from .. import Provider as BaseProvider


class Provider(BaseProvider):

    # Sources:
    #   - https://www.ons.dz/IMG/file/Profession.pdf
    jobs_male = (
        "أستاذ",
        "أخصائي اجتماعي",
        "إداري",
        "إطار",
        "بائع",
        "تاجر",
        "تقني",
        "تقني سامٍ",
        "جراح",
        "حارس أمن",
        "خبير اقتصادي",
        "خبير محاسب",
        "سائق",
        "شرطي",
        "صحفي",
        "صيدلي",
        "طبيب",
        "طبيب أسنان",
        "طبيب بيطري",
        "طيار",
        "عامل",
        "فلاح",
        "قاضي",
        "كاتب عمومي",
        "مبرمج",
        "مترجم",
        "محامي",
        "محاسب",
        "محرر",
        "مدرب",
        "مدير",
        "مدير مشروع",
        "مرشد سياحي",
        "مستشار قانوني",
        "مصمم",
        "مصمم جرافيك",
        "مصور",
        "معلم",
        "مفتش",
        "مقاول",
        "ممرض",
        "ممثل تجاري",
        "موظف إداري",
        "موظف بنكي",
        "مهندس",
        "مهندس بترولي",
        "مهندس معماري",
        "ميكانيكي",
        "نجار",
        "وكيل عقاري",
    )

    jobs_female = (
        "أستاذة",
        "أخصائية اجتماعية",
        "إدارية",
        "إطارة",
        "بائعة",
        "تاجرة",
        "تقنية",
        "تقنية سامية",
        "جراحة",
        "حارسة أمن",
        "خبيرة اقتصادية",
        "خبيرة محاسبة",
        "سائقة",
        "شرطية",
        "صحفية",
        "صيدلانية",
        "طبيبة",
        "طبيبة أسنان",
        "طبيبة بيطرية",
        "طيارة",
        "عاملة",
        "فلاحة",
        "قاضية",
        "كاتبة عمومية",
        "مبرمجة",
        "مترجمة",
        "محامية",
        "محاسبة",
        "محررة",
        "مدربة",
        "مديرة",
        "مديرة مشروع",
        "مرشدة سياحية",
        "مستشارة قانونية",
        "مصممة",
        "مصممة جرافيك",
        "مصورة",
        "معلمة",
        "مفتشة",
        "مقاولة",
        "ممرضة",
        "ممثلة تجارية",
        "موظفة إدارية",
        "موظفة بنكية",
        "مهندسة",
        "مهندسة بترولية",
        "مهندسة معمارية",
        "ميكانيكية",
        "وكيلة عقارية",
    )

    jobs = jobs_male + jobs_female
