from .. import Provider as BaseProvider


class Provider(BaseProvider):
    # Sourse: https://www.ganmarteba.ge/
    jobs = [
        "ავიადისპეტჩერი",
        "ამწე ოპერატორი",
        "ავიატექნიკოსი",
        "ავიაციის ტექნიკოსი",
        "აეროპლანის მფრინავი",
        "აკუსტიკის ინჟინერი",
        "აღმზრდელი",
        "აღმოსავლეთმცოდნე",
        "ავტოელექტრიკოსი",
        "აგრონომი",
        "არტისტი",
        "აგრონომ-ნიადაგმცოდნე",
        "ადვოკატი",
        "აკუმულატორების სპეციალისტი",
        "აქტუარი",
        "ალერგოლოგი",
        "ანალიტიკოსი",
        "ანდროლოგი",
        "ანთროპოლოგი",
        "არტილერისტი",
        "არქეოლოგი",
        "არქივარიუსი",
        "არქიტექტორი",
        "ასტრონომი",
        "ასტрофიზიკოსი",
        "ასტროქიმიკოსი",
        "ბაქტერიოლოგი",
        "ბალერინა",
        "ბალეტმაისტერი",
        "ბანკირი",
        "ბარმენი",
        "ბატალერი",
        "ბიბლიოთეკარი",
        "ბიბლიოთეკმცოდნე",
        "ბიონჟინერი",
        "ბიოლოგი",
        "ბიოფიზიკოსი",
        "ბიოქიმიკოსი",
        "ბლოგერი",
        "ბორტ-ინჟინერი",
        "ბორტ-მექანიკოსი",
        "ბორტ-რადისტი",
        "ბოტანიკოსი",
        "ბრეიდერი",
        "ბროკერი",
        "პურის მცხობელი",
        "ბულდოზერისტი",
        "ბუღალტერი",
        "გასტროენტეროლოგი",
        "გემის კაპიტანი",
        "გაუპვახტის უფროსი",
        "გამომძიებელი",
        "გალვანიკური ინჟინერი",
        "გამომცემელი",
        "გამომგონებელი",
        "გენეტიკოსი",
        "გეოგრაფი",
        "გეოდეზისტი",
        "გამყიდველი",
        "გეოლოგი",
        "გინეკოლოგი",
        "გიტარისტი",
        "გლაციოლოგი",
        "გრანატომტყორცნელი",
        "გრეიდერის ოპერატორი",
        "გრენადერი",
        "გრიმიორი",
        "გამომცემელი რედაქტორი",
        "დიზაინის ინჟინერი",
        "დეკანი",
        "დეკორატორი",
        "დურგალი",
        "დერმატოლოგი",
        "დეტექტივი",
        "დეფექტოლოგი",
        "დიჯეი",
        "დიეტოლოგი",
        "დიზაინერი",
        "დიზაინერი-კონსტრუქტორი",
        "დიქტორი",
        "დილერი",
        "დიპლომატი",
        "დიპლომატიური მუშაკი",
        "დირიჟორი",
        "დრეპერი",
        "დამლაგებელი",
        "ეკოლოგი",
        "ეკონომისტი",
        "ექსპედიტორი",
        "ექიმი ულტრაბგერითი დიაგნოსტიკის",
        "ეგვიპტოლოგი",
        "ექსპერტ-კრიმინალისტი",
        "ელექტრიკოსი",
        "ელექტროინჟინერი",
        "ენერგეტიკის ინჟინერი",
        "ენდოკრინოლოგი",
        "ენდოსკოპისტი",
        "ენტომოლოგი",
        "ეპიდემიოლოგი",
        "ეფერენტოლოგი",
        "ვებ-ინტეგრატორი",
        "ვებ-მასტერი",
        "ვებ-პროგრამისტი",
        "ვეტერინარი",
        "ვიზაჟისტი",
        "ვაზის მეღვინე",
        "ვირუსოლოგი",
        "ვოკალისტი",
        "ზეინკალი",
        "ზოოლოგი",
        "თეოლოგი",
        "თერაპევტი",
        "თერიოლოგი",
        "თიფლოპედაგოგი",
        "თორაკალური ქირურგი",
        "თარჯიმანი",
        "ილუსტრატორი",
        "იმიჯმეიკერი",
        "იმუნოლოგი",
        "იუველირი",
        "იურიდიული მრჩეველი",
        "იურისტი",
        "ინჟინერი",
        "ინკასატორი",
        "ინტენდანტი",
        "ინფექციონისტი",
        "ისტორიკოსი",
        "იქთიოლოგი",
        "კომპიუტერული ინჟინერი",
        "კინოსა და ტელევიზიის ოპერატორი",
        "კარდიოლოგი",
        "კარდიოქირურგი",
        "კასკადიორი",
        "კომპიუტერის ოპერატორი",
        "კასირი",
        "კინოლოგი",
        "კრიპტოგრაფი",
        "კინომექანიკოსი",
        "კინოოპერატორი",
        "კინორეჟისორი",
        "კლიენტთა ურთიერთობის მენეჯერი",
        "კოდერი",
        "კომენდანტი",
        "კომერციული დირექტორი",
        "კომპოზიტორი",
        "კონდიტერი",
        "კონდუქტორი",
        "კონტენტის მენეჯერი",
        "კოპირაიტერი",
        "კორექტორ-მთავარი",
        "კორექტორი",
        "კოსმეტოლოგი",
        "კოსმონავტი",
        "კრიპტოზოოლოგი",
        "კრიტიკოსი",
        "კულტუროლოგი",
        "ლაბორანტი",
        "ლიმფოლოგი",
        "ლინგვისტი",
        "ლოგოპედი",
        "ლოცმანი",
        "ლაბორანტი-ინჟინერი",
        "ლოკომოტივის მძღოლი",
        "ლექტორი",
        "მალარი",
        "მამმოლოგი",
        "მხატვარი",
        "მცხობელი",
        "მანუალისტი",
        "მარკეტოლოგი",
        "მასაჟისტი",
        "მწყემსი",
        "მანიკიურის ოსტატი",
        "მათემატიკოსი",
        "მატარებლის მძღოლი",
        "მცენარეთა სპეციალისტი",
        "მეწარმე",
        "მექანიზაციის ინჟინერი",
        "მოცეკვავე",
        "მძღოლი",
        "მსახიობი",
        "მეანე",
        "მესაზღვრე",
        "მეხანძრე",
        "მეხორბლე",
        "მიმტანი",
        "მეფუტკრე",
        "მწერალი",
        "მენეჯერი",
        "მეტალურგი",
        "მეტეოროლოგი",
        "მჭედელი",
        "მებაჟე",
        "მექანიკოსი",
        "მეცხოველეობის სპეციალისტი",
        "მეტყევე-ინჟინერი",
        "მედესანტე",
        "მექანიკის ინჟინერი",
        "მცენარეთა დაცვის აგრონომი",
        "მკერავი",
        "მტვირთავი",
        "მიკრობიოლოგი",
        "მინისტრი",
        "მოდელი",
        "მოდელიერი",
        "მებაღე",
        "მასწავლებელი",
        "მაღაროელი",
        "მეცნიერი",
        "მეწაღე",
        "მოქანდაკე",
        "მთამსვლელი",
        "მყვინთავი",
        "მეურნე",
        "მონტაჟნიკი",
        "მსაჯი",
        "მონაცემთა ბაზის ადმინისტრატორი",
        "მუსიკოსი",
        "მშენებელი",
        "ნარკოლოგი",
        "ნევროლოგი",
        "ნევროპათოლოგი",
        "ნეიროქირურგი",
        "ნეონატოლოგი",
        "ნეფროლოგი",
        "ნოტარიუსი",
        "ოკეანოლოგი",
        "ონკოლოგი",
        "ორნითოლოგი",
        "ორთოდონტი",
        "ორთოპედი",
        "ოტორინოლარინგოლოგი",
        "ოფთალმოლოგი",
        "ოჯახის ექიმი",
        "პილოტი",
        "პალეონტოლოგი",
        "პედიკიურის ოსტატი",
        "პარფიუმერი",
        "პასტორალისტი",
        "პათოლოგანატომი",
        "პედაგოგი",
        "პედიატრი",
        "პლასტიკური ქირურგი",
        "პოლიტოლოგი",
        "პოლიციელი",
        "პოეტი",
        "პროგრამისტი",
        "პროდიუსერი",
        "პირადი მცველი",
        "პროქტოლოგი",
        "პროფესიული პათოლოგი",
        "პულმონოლოგი",
        "ჟურნალისტი",
        "რეკლამის დიზაინერი",
        "რადიოლოგი",
        "რადიომექანიკოსი",
        "რადიოტელეფონისტი",
        "რადისტი",
        "რადიოლოკაციური სისტემის ოპერატორი",
        "რეანიმატოლოგი",
        "რევმატოლოგი",
        "რედაქტორი",
        "რეჟისორი",
        "რელიგიური მეცნიერი",
        "რენტგენოლოგი",
        "რესტავრატორი",
        "რეფლექსოთერაპევტი",
        "რიხტოვშიკი",
        "რობოტოტექნიკოსი",
        "სანიტარი",
        "სანტექნიკოსი",
        "საპიორი",
        "სასულიერო პირი",
        "სექსოლოგი",
        "სექსოპათოლოგი",
        "სერპენტოლოგი",
        "სისტემური ადმინისტრატორი",
        "სნაიპერი",
        "სომელიე",
        "სასაქონლო ექსპერტი",
        "სპილენძის მჭედელი",
        "სომნოლოგი",
        "სოციოლოგი",
        "სპორტული ექიმი",
        "სახელმწიფო აღმასრულებელი",
        "სამხედრო ქირურგი",
        "სამხედრო მოსამსახურე",
        "სამხედრო გამომძიებელი",
        "სამხედრო კონსულტანტი",
        "სამხედრო მთარგმნელი",
        "სამხედრო პოლიციელი",
        "საგადასახადო ინსპექტორი",
        "საწყობის უფროსი",
        "სამხედრო პროკურორი",
        "სამხედრო მოსამართლე",
        "სამედიცინო და სოციალური ექსპერტიზის ექიმი",
        "სამხედრო ინჟინერი",
        "საკრედიტო კონსულტანტი",
        "სამხედრო იურისტი",
        "სასწრაფო დახმარების ექიმი",
        "სტიუარდი",
        "სტომატოლოგი",
        "სამართალმცოდნე",
        "სადაზღვევო აგენტი",
        "სასამართლო აღსრულების სპეციალისტი",
        "სტილისტი",
        "სამხედრო ორკესტრის უფროსი",
        "სურდოლოგი",
        "სურდოპედაგოგი",
        "სცენარისტი",
        "სისტემატიკის ინჟინერი",
        "სამშენებლო ინჟინერი",
        "ტაქსის მძღოლი",
        "ტალმანი",
        "ტანატოლოგი",
        "ტანკისტი",
        "ტატუს ოსტატი",
        "ტელეგრაფისტი",
        "ტელეჟურნალისტი",
        "ტელევიზიის ოსტატი",
        "ტესტირების სპეციალისტი",
        "ტექნიკოსი",
        "ტექნოლოგი",
        "ტიპოგრაფი",
        "ტექნოლოგიური ინჟინერი",
        "ტოქსიკოლოგი",
        "ტოპოგრაფი",
        "ტრავმატოლოგი",
        "ტრაქტორისტი",
        "ტრანსფუზიოლოგი",
        "ტრედერი",
        "ტრენდ-ვოჩერი",
        "უროლოგი",
        "უმუშევარი",
        "უსაფრთხოების ტექნიკის ინჟინერი",
        "უჯრედული ტექნოლოგიების სპეციალისტი",
        "ფიზიკის ინჟინერი",
        "ფოსტალიონი",
        "ფსიქიატრი",
        "ფარმაცევტი",
        "ფიზიკოსი",
        "ფიზიოთერაპევტი",
        "ფილოლოგი",
        "ფილოსოფოსი",
        "ფინანსისტი",
        "ფლებოლოგი",
        "ფლორისტი",
        "ფოტოგრაფი",
        "ფოტომოდელი",
        "ფურაჟირი",
        "ფუტუროლოგი",
        "ფოლადის მწარმოებელი",
        "ფსიქონევროპათოლოგი",
        "ფუნქციური დიაგნოსტიკის ექიმი",
        "ფსიქოთერაპევტი",
        "ფსიქოლოგი",
        "ქვისმთლელი",
        "ქიმიის ინჟინერი",
        "ქიმიკოსი",
        "ქიმიკოს-ტექნოლოგი",
        "ქირურგი",
        "ქორეოგრაფი",
        "ქოლცენტრის ოპერატორი",
        "ქორწილების ორგანიზატორი",
        "ქვაფენილი",
        "ქუჩის დამლაგებელი",
        "ყველის მწარმოებელი",
        "შტაბის უფროსი",
        "შემკრებავი",
        "შემდუღებელი",
        "ცხვრის მჭრელი სპეციალისტი",
        "ცირკის არტისტი",
        "ცხენმშენებელი",
        "ციხის ზედამხედველი",
        "ძიძა",
        "ხარატი",
        "ხმის ინჟინერი",
        "ხელოვნებათმცოდნე",
        "ჯალათი",
        "ჰემატოლოგი",
        "ჰეპატოლოგი",
        "ჰიდროლოგი",
        "ჰომეოპათი",
        "ჰირუდოთერაპევტი",
        "ჰიდრავლიკის ინჟინერი",
    ]
