from typing import Dict

from .. import Provider as LoremProvider


class Provider(LoremProvider):
    """Lorem provider for mk_MK locale (Macedonian)."""

    word_list = (
        "луѓе",
        "живот",
        "работа",
        "време",
        "место",
        "свет",
        "земја",
        "град",
        "куќа",
        "пат",
        "ден",
        "ноќ",
        "вода",
        "сонце",
        "небо",
        "страна",
        "рака",
        "очи",
        "глава",
        "срце",
        "деца",
        "мајка",
        "татко",
        "брат",
        "сестра",
        "пријател",
        "љубов",
        "среќа",
        "мир",
        "народ",
        "слобода",
        "правда",
        "вистина",
        "убавина",
        "природа",
        "шума",
        "река",
        "море",
        "планина",
        "село",
        "улица",
        "прозорец",
        "врата",
        "книга",
        "музика",
        "песна",
        "уметност",
        "историја",
        "култура",
        "јазик",
        "зборови",
        "мисла",
        "чувство",
        "сон",
        "надеж",
        "иднина",
        "минато",
        "сегашност",
        "знаење",
        "образование",
        "наука",
        "технологија",
        "компјутер",
        "интернет",
        "телефон",
        "информација",
        "вест",
        "проблем",
        "решение",
        "прашање",
        "одговор",
        "можност",
        "промена",
        "развиток",
        "успех",
        "цел",
        "план",
        "идеја",
        "создавање",
        "градење",
        "заедница",
        "семејство",
        "пријателство",
        "соработка",
        "разбирање",
        "доверба",
        "поддршка",
        "помош",
        "грижа",
        "здравје",
        "храна",
        "леб",
        "вино",
        "сол",
        "светлина",
        "темнина",
        "топлина",
        "студ",
        "дожд",
        "ветер",
        "снег",
        "оган",
        "земјиште",
        "камен",
        "песок",
        "злато",
        "сребро",
        "железо",
        "дрво",
        "лист",
        "цвет",
        "трева",
        "жито",
        "овошје",
        "зеленчук",
        "риба",
        "птица",
        "коњ",
        "куче",
        "мачка",
        "волк",
        "мечка",
        "орел",
        "небесен",
        "длабок",
        "висок",
        "широк",
        "тесен",
        "голем",
        "мал",
        "стар",
        "млад",
        "убав",
        "добар",
        "лош",
        "силен",
        "слаб",
        "брз",
        "бавен",
        "тивок",
        "гласен",
        "светол",
        "темен",
        "топол",
        "ладен",
        "тежок",
        "лесен",
        "трчи",
        "оди",
        "лета",
        "пее",
        "зборува",
        "пишува",
        "чита",
        "гледа",
        "слуша",
        "мисли",
        "сака",
        "знае",
        "може",
        "дава",
        "зема",
        "прави",
        "живее",
        "расте",
        "учи",
        "работи",
        "игра",
        "спие",
        "јаде",
        "пие",
        "смее",
        "плаче",
        "денес",
        "утре",
        "вчера",
        "сега",
        "тука",
        "таму",
        "многу",
        "малку",
        "секогаш",
        "никогаш",
        "брзо",
        "полека",
        "добро",
        "лошо",
        "заедно",
        "сам",
        "прво",
        "потоа",
        "пред",
        "после",
        "горе",
        "доле",
        "лево",
        "десно",
        "внатре",
        "надвор",
        "зошто",
        "затоа",
        "ако",
        "кога",
        "каде",
        "кој",
        "што",
    )

    parts_of_speech: Dict[str, tuple] = {}
