from .. import Provider as BaseProvider


class Provider(BaseProvider):
    """Job provider for mk_MK locale (Macedonian)."""

    jobs = (
        "Агроном",
        "Адвокат",
        "Администратор",
        "Аналитичар",
        "Архитект",
        "Биолог",
        "Биохемичар",
        "Бравар",
        "Ветеринар",
        "Водоинсталатер",
        "Возач",
        "Геодет",
        "Геолог",
        "Градежен инженер",
        "Графички дизајнер",
        "Директор",
        "Доктор по медицина",
        "Економист",
        "Електричар",
        "Електроинженер",
        "Електротехничар",
        "Журналист",
        "Ѕидар",
        "Забар",
        "Инспектор",
        "Информатичар",
        "Истражувач",
        "Книговодител",
        "Козметичар",
        "Конструктор",
        "Кувар",
        "Лекар",
        "Логопед",
        "Мајстор",
        "Машински инженер",
        "Менаџер",
        "Механичар",
        "Молер",
        "Наставник",
        "Нотар",
        "Нутриционист",
        "Пекар",
        "Пилот",
        "Планер",
        "Полицаец",
        "Правник",
        "Програмер",
        "Психолог",
        "Референт",
        "Сoобраќаен инженер",
        "Секретар",
        "Сметководител",
        "Социјален работник",
        "Столар",
        "Стоматолог",
        "Судија",
        "Технолог",
        "Технолошки инженер",
        "Трговец",
        "Учител",
        "Фармацевт",
        "Физиотерапевт",
        "Финансиски аналитичар",
        "Хемичар",
        "Шумар",
    )
