from .. import Provider as BaseProvider


class Provider(BaseProvider):

    # Sources:
    #   - https://www.ons.dz/IMG/file/Profession.pdf
    jobs_male = (
        "accompagnateur de tourisme",
        "acheteur",
        "adjoint administratif",
        "agent commercial",
        "agent de sécurité",
        "agent des douanes",
        "agent des impôts",
        "analyste financier",
        "architecte",
        "archiviste",
        "assistant de direction",
        "assistant social",
        "attaché de presse",
        "auditeur",
        "avocat",
        "biologiste",
        "cadre administratif",
        "cadre bancaire",
        "cadre commercial",
        "cadre de la fonction publique",
        "chargé d'études",
        "chargé de communication",
        "chargé de projet",
        "chauffeur",
        "chef de chantier",
        "chef de projet informatique",
        "chef de service",
        "chirurgien",
        "commis de cuisine",
        "comptable",
        "conducteur de travaux",
        "conseiller juridique",
        "contrôleur de gestion",
        "déclarant en douane",
        "dentiste",
        "dessinateur industriel",
        "développeur informatique",
        "directeur commercial",
        "directeur des ressources humaines",
        "directeur financier",
        "directeur général",
        "directeur technique",
        "économiste",
        "électricien de bâtiment",
        "employé administratif",
        "employé de banque",
        "enseignant du primaire",
        "enseignant du secondaire",
        "enseignant-chercheur",
        "expert judiciaire",
        "expert-comptable",
        "fonctionnaire",
        "formateur professionnel",
        "géologue",
        "géomètre-topographe",
        "gestionnaire de paie",
        "guide touristique",
        "huissier de justice",
        "hydraulicien",
        "infirmier",
        "ingénieur chimiste",
        "ingénieur civil",
        "ingénieur d'état",
        "ingénieur électricien",
        "ingénieur électronicien",
        "ingénieur en génie civil",
        "ingénieur en informatique",
        "ingénieur en télécommunications",
        "ingénieur géologue",
        "ingénieur mécanicien",
        "ingénieur pétrolier",
        "inspecteur de l'éducation",
        "inspecteur des impôts",
        "interprète",
        "journaliste",
        "juge",
        "juriste",
        "kinésithérapeute",
        "laborantin",
        "logisticien",
        "magistrat",
        "maître assistant",
        "maître de conférences",
        "maïeuticien",
        "médecin généraliste",
        "médecin spécialiste",
        "médecin vétérinaire",
        "menuisier",
        "notaire",
        "officier de police judiciaire",
        "opérateur de forage",
        "pharmacien",
        "plombier",
        "pompier",
        "procureur de la République",
        "professeur de lycée",
        "professeur de l'enseignement supérieur",
        "psychologue",
        "rédacteur",
        "représentant commercial",
        "responsable informatique",
        "responsable qualité",
        "secrétaire",
        "soudeur",
        "surveillant général",
        "technicien de laboratoire",
        "technicien en électricité",
        "technicien en informatique",
        "technicien en télécommunications",
        "technicien supérieur",
        "topographe",
        "traducteur",
        "travailleur social",
    )

    jobs_female = (
        "accompagnatrice de tourisme",
        "acheteuse",
        "adjointe administrative",
        "agente commerciale",
        "agente de sécurité",
        "agente des douanes",
        "agente des impôts",
        "analyste financière",
        "architecte",
        "archiviste",
        "assistante de direction",
        "assistante sociale",
        "attachée de presse",
        "auditrice",
        "avocate",
        "biologiste",
        "cadre administrative",
        "cadre bancaire",
        "cadre commerciale",
        "cadre de la fonction publique",
        "chargée d'études",
        "chargée de communication",
        "chargée de projet",
        "chauffeuse",
        "cheffe de chantier",
        "cheffe de projet informatique",
        "cheffe de service",
        "chirurgienne",
        "commise de cuisine",
        "comptable",
        "conductrice de travaux",
        "conseillère juridique",
        "contrôleuse de gestion",
        "déclarante en douane",
        "dentiste",
        "dessinatrice industrielle",
        "développeuse informatique",
        "directrice commerciale",
        "directrice des ressources humaines",
        "directrice financière",
        "directrice générale",
        "directrice technique",
        "économiste",
        "électricienne de bâtiment",
        "employée administrative",
        "employée de banque",
        "enseignante du primaire",
        "enseignante du secondaire",
        "enseignante-chercheuse",
        "experte judiciaire",
        "experte-comptable",
        "fonctionnaire",
        "formatrice professionnelle",
        "géologue",
        "géomètre-topographe",
        "gestionnaire de paie",
        "guide touristique",
        "huissière de justice",
        "hydraulicienne",
        "infirmière",
        "ingénieure chimiste",
        "ingénieure civile",
        "ingénieure d'état",
        "ingénieure électricienne",
        "ingénieure électronicienne",
        "ingénieure en génie civil",
        "ingénieure en informatique",
        "ingénieure en télécommunications",
        "ingénieure géologue",
        "ingénieure mécanicienne",
        "ingénieure pétrolière",
        "inspectrice de l'éducation",
        "inspectrice des impôts",
        "interprète",
        "journaliste",
        "juge",
        "juriste",
        "kinésithérapeute",
        "laborantine",
        "logisticienne",
        "magistrate",
        "maître assistante",
        "maître de conférences",
        "sage-femme",
        "médecin généraliste",
        "médecin spécialiste",
        "médecin vétérinaire",
        "menuisière",
        "notaire",
        "officière de police judiciaire",
        "opératrice de forage",
        "pharmacienne",
        "plombière",
        "pompière",
        "procureure de la République",
        "professeure de lycée",
        "professeure de l'enseignement supérieur",
        "psychologue",
        "rédactrice",
        "représentante commerciale",
        "responsable informatique",
        "responsable qualité",
        "secrétaire",
        "soudeuse",
        "surveillante générale",
        "technicienne de laboratoire",
        "technicienne en électricité",
        "technicienne en informatique",
        "technicienne en télécommunications",
        "technicienne supérieure",
        "topographe",
        "traductrice",
        "travailleuse sociale",
    )

    jobs = jobs_male + jobs_female
